import numpy as np
from gpaw.xc.libvdwxc import LibVDWXC, FFTDistribution
from gpaw.grid_descriptor import GridDescriptor
from gpaw.mpi import world
from optparse import OptionParser
from ase.utils.timing import Timer

oldworld = world
world = world.new_communicator(range(8))
if world is not None:
    p = OptionParser()
    opts, args = p.parse_args()
    if len(args) == 3:
        X, Y, Z = map(int, args)
    elif len(args) == 0:
        X, Y, Z = 30, 20, 10
    else:
        p.error('Zero or 3 args please')

    N_c = np.array([X, Y, Z])

    gd = GridDescriptor(N_c, N_c * 0.15, comm=world)
    dist = FFTDistribution(gd, (world.size, 1, 1))

    gen = np.random.RandomState(0)

    n_g = dist.block_zeros()
    gradn_g = dist.block_zeros()
    dedn_g = dist.block_zeros()
    dedsigma_g = dist.block_zeros()

    for arr in [n_g, gradn_g]:
        arr.flat[:] = gen.rand(arr.size)

    xc = LibVDWXC('vdW-DF-CX', N_c, gd.cell_cv, world)
    print xc.tostring()
    world.barrier()
    for i in range(10):
        e = xc.calculate(n_g, gradn_g, dedn_g, dedsigma_g)
        print world.sum(e)

oldworld.barrier()
